==> micronaut-serde-support-1.5.2-sources.jar: io/micronaut/serde/support/serdes/InstantSerde.java <==
/*
 * Copyright 2017-2021 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.serde.support.serdes;

import java.io.IOException;
import java.time.Instant;
import java.time.format.DateTimeFormatter;
import java.time.temporal.TemporalQuery;

import io.micronaut.core.type.Argument;
import io.micronaut.serde.Decoder;
import io.micronaut.serde.Encoder;
import io.micronaut.serde.config.SerdeConfiguration;
import jakarta.inject.Singleton;

/**
 * Serde used for {@link java.time.Instant}.
 *
 * @since 1.0.0
 */
@Singleton
public class InstantSerde extends DefaultFormattedTemporalSerde<Instant> implements TemporalSerde<Instant> {

    private static final TemporalQuery<Instant> QUERY = Instant::from;

    protected InstantSerde(SerdeConfiguration configuration) {
        super(configuration);
    }

    @Override
    protected DateTimeFormatter getDefaultFormatter() {
        return DateTimeFormatter.ISO_INSTANT;
    }

    @Override
    public TemporalQuery<Instant> query() {
        return QUERY;
    }

    @Override
    protected void serializeWithoutFormat(Encoder encoder, EncoderContext context, Instant value, Argument<? extends Instant> type) throws IOException {
        encoder.encodeLong(value.toEpochMilli());
    }

    @Override
    protected Instant deserializeNonNullWithoutFormat(Decoder decoder, DecoderContext decoderContext, Argument<? super Instant> type) throws IOException {
        return Instant.ofEpochMilli(decoder.decodeLong());
    }
}

==> micronaut-serde-support-2.2.4-sources.jar: io/micronaut/serde/support/serdes/InstantSerde.java <==
/*
 * Copyright 2017-2021 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.serde.support.serdes;

import io.micronaut.serde.config.SerdeConfiguration;
import jakarta.inject.Singleton;

import java.time.Instant;
import java.time.format.DateTimeFormatter;
import java.time.temporal.TemporalQuery;

/**
 * Serde used for {@link java.time.Instant}.
 *
 * @since 1.0.0
 */
@Singleton
public final class InstantSerde extends NumericSupportTemporalSerde<Instant> implements TemporalSerde<Instant> {

    private static final TemporalQuery<Instant> QUERY = Instant::from;

    InstantSerde(SerdeConfiguration configuration) {
        super(configuration, DateTimeFormatter.ISO_INSTANT, SerdeConfiguration.NumericTimeUnit.MILLISECONDS);
    }

    @Override
    public TemporalQuery<Instant> query() {
        return QUERY;
    }

    @Override
    protected long getSecondPart(Instant value) {
        return value.getEpochSecond();
    }

    @Override
    protected int getNanoPart(Instant value) {
        return value.getNano();
    }

    @Override
    protected Instant fromNanos(long seconds, int nanos) {
        return Instant.ofEpochSecond(seconds, nanos);
    }
}
